@@ -150,6 +150,7 @@ class Inqman_InquiryController extends AbstractController
                 Inqman_InquiryForm::SUBJECT       => "",
                 Inqman_InquiryForm::RECEIVED_FROM => "",
                 Inqman_InquiryForm::CONTENT       => "",
+                Inqman_InquiryForm::PARENT_INQ_ID => 0,
             );
         }
         
@@ -284,6 +285,7 @@ class Inqman_InquiryController extends AbstractController
                 
             //承認フローが無効の場合は、同時に承認処理も行う
             if (intval($this->_config->workflow->approve->inquiry->accept) != 1) {
+                $values['approver_id'] = $this->_getUserInfo()->id;
                 $inquiry_model->approveInquiry($inquiry_id, $values);
             }
             
@@ -447,6 +449,7 @@ class Inqman_InquiryController extends AbstractController
         $this->view->assign('priority_options', $priority_options);
         $this->view->assign('service_options', $service_options);
         $this->view->assign('user_options', $user_options);
+        $this->view->assign('workflow_approve', intval($this->_config->workflow->approve->inquiry->accept));
         
         //アクセス権限情報を取得
         $this->_assignAclFlag($service_id, $inquiry_id);
@@ -953,6 +956,7 @@ class Inqman_InquiryController extends AbstractController
                 
             //承認フローが無効の場合は、同時に承認処理も行う
             if (intval($this->_config->workflow->approve->inquiry->accept) != 1) {
+                $values['approver_id'] = $this->_getUserInfo()->id;
                 $inquiry_model->approveInquiry($inquiry_id, $values);
             }
             
@@ -1231,6 +1235,7 @@ class Inqman_InquiryController extends AbstractController
     {
         $tmp = array();
         $tmp[] = $row['id'];
+        $tmp[] = empty($row['service_name']) ? "--" : $this->view->escape($row['service_name']);
         $tmp[] = '<a href="' . $ctrlName . '/view_detail/inquiry_id/' . $row['id'] . '/">' . $this->view->escape($row['subject']) . '</a>';
         $tmp[] = empty($row['received_from']) ? "--" : $this->view->escape($row['received_from']);
         $tmp[] = empty($row['content']) ? "--" : $this->view->escape(mb_strcut($row['content'], 0, 200, 'UTF-8').'...');
@@ -1271,4 +1276,4 @@ class Inqman_InquiryController extends AbstractController
         }
         return $ctrlName;
     }
-}
\ No newline at end of file
+}
