@@ -937,7 +937,14 @@ class Inqman_InquiryModel extends Inqman_AbstractDao
                         $select->where("i.subject like ?", "%{$value}%");
                     }
                     break;
-                    
+                case 'from':
+                    if ($cond['mtd']=='equal' && !empty($cond['val'])) {
+                        $select->where("i.received_from=?", $cond['val']);
+                    } elseif($cond['mtd']=='like' && !empty($cond['val'])) {
+                        $value = $cond['val'];
+                        $select->where("i.received_from like ?", "%{$value}%");
+                    }
+                    break;
                 case 'cdt':
                     $sdate = $cond['sd'];
                     $stime = $cond['st'];
@@ -947,13 +954,13 @@ class Inqman_InquiryModel extends Inqman_AbstractDao
                     if (!empty($sdate)) {
                         if (empty($stime)) $stime = "00:00";
                         $sdt = "{$sdate} {$stime}";
-                        $select->where('create_datetime > ?', $sdt);
+                        $select->where('i.create_datetime > ?', $sdt);
                     }
                     
                     if (!empty($edate)) {
                         if (empty($etime)) $etime = "23:59";
                         $edt = "{$edate} {$etime}";
-                        $select->where('create_datetime < ?', $edt);
+                        $select->where('i.create_datetime < ?', $edt);
                     }
                     
                     break;
@@ -1052,6 +1059,9 @@ class Inqman_InquiryModel extends Inqman_AbstractDao
             case "operator":
                 $col = self::OPERATOR_ID;
                 break;
+            case "service":
+                $col = 'service_name';
+                break;
             default:
                 $col = self::ID;
                 break;
@@ -1066,4 +1076,4 @@ class Inqman_InquiryModel extends Inqman_AbstractDao
         return "{$col} {$row}";
     }
         
-}
\ No newline at end of file
+}
