@@ -82,7 +82,7 @@ class Inqman_PopServer
             //受信済みのメール情報（ユニークID）を取得
             $maildump_model = new Inqman_MaildumpModel();
             $ids = $maildump_model->getReceivedUniqueId();
-            
+
             try {
                 //POP3サーバに接続
                 $this->_connect($setting);
@@ -104,7 +104,7 @@ class Inqman_PopServer
                     if ($result == 'inquiry') $inquiry_count++;
                     elseif($result == 'reply') $reply_count++;
                     elseif($result == 'comment') $comment_count++;
-                    
+
                     //メールをそのままDBに保存する
                     if (!empty($result)) {
                         $this->_saveMessage($uid, $message);
@@ -131,7 +131,10 @@ class Inqman_PopServer
         $service_code = $service['code'];
         $subject = $values['subject'];
         $inquiry_number = $this->_extractId($subject, $service_code);
-        
+
+        //件名から接頭辞を除去
+        $values['subject'] = preg_replace('/\['.$service_code.':[0-9]+\]/i', '', $subject);
+
         if (empty($inquiry_number)) {
             if ($this->_registerInquiry($values, $service_id)) {
                 return 'inquiry';
@@ -202,17 +205,22 @@ class Inqman_PopServer
             return false;
         }
         
+        $mailaddress = "";
         preg_match('/([0-9a-zA-Z\-\.\_]+\@[0-9a-zA-Z\-\.]+)/', $values['from'], $matches);
-        $mailaddress = $matches[0];
+        if (!empty($matches)) {
+            $mailaddress = $matches[0];
+        }
         
-        $this->_checkAclByMailaddress($mailaddress, ACL_RESOURCE_KEY_REPLY, ACL_PRIVILEGE_KEY_CREATE, $service_id);
+        //送信者がシステムユーザの場合、IDを取得
+        $respondent_id = 0;
         $respondent = $user_model->getOneUserByMailaddress($mailaddress);
-        
+        if (!empty($respondent)) $respondent_id = $respondent['id'];
+
         $reply = array(
             'type'            => 1,
             'subject'         => $values['subject'],
             'received_from'   => $values['from'],
-            'respondent_id'   => $respondent['id'],
+            'respondent_id'   => $respondent_id,
             'priority'        => $values['priority'],
             'content'         => $values['content'],
             'inquiry_id'      => $inquiry_id,
@@ -220,14 +228,10 @@ class Inqman_PopServer
             'reply_datetime'  => date("Y-m-d H:i:s", time()),
             'message_id'      => $values['message_id'],
         );
-        
+       
         if ($status == Inqman_InquiryModel::STATUS_CODE_UNASSIGN) {
-            $inquiry_model->assignOperator($inquiry_id, $respondent['id']);
-        } else if($inquiry['operator_id'] != $respondent['id']) {
-            //TODO ERROR
-            return false;
+            $inquiry_model->assignOperator($inquiry_id, $respondent_id);
         }
-        
         $reply_id = $reply_model->createReply($reply);
         
         //メール送信処理
@@ -259,16 +263,20 @@ class Inqman_PopServer
         }
         
         preg_match('/([0-9a-zA-Z\-\.\_]+\@[0-9a-zA-Z\-\.]+)/', $values['from'], $matches);
-        $mailaddress = $matches[0];
+        if (!empty($matches)) {
+            $mailaddress = $matches[0];
+        }
         
-        $this->_checkAclByMailaddress($mailaddress, ACL_RESOURCE_KEY_COMMENT, ACL_PRIVILEGE_KEY_CREATE, $service_id);
+        //送信者がシステムユーザの場合、IDを取得
+        $respondent_id = 0;
         $respondent = $user_model->getOneUserByMailaddress($mailaddress);
+        if (!empty($respondent)) $respondent_id = $respondent['id'];
         
         $reply = array(
             'type'            => 2,
             'subject'         => $values['subject'],
             'received_from'   => $values['from'],
-            'respondent_id'   => $respondent['id'],
+            'respondent_id'   => $respondent_id,
             'priority'        => $values['priority'],
             'content'         => $values['content'],
             'inquiry_id'      => $inquiry_id,
@@ -292,7 +300,10 @@ class Inqman_PopServer
         $inquiry_id = 0;
         if(!empty($subject)) {
             preg_match('/\['. $service_code .':[0-9]+\]/i', $subject, $match_str);
-            if (isset($match_str[0])) preg_match('/[0-9]+/', $match_str[0], $match_number);
+            if (isset($match_str[0])) {
+                $match_str[0] = str_replace($service_code . ':', '', $match_str[0]);
+                preg_match('/[0-9]+/', $match_str[0], $match_number);
+            }
             if (isset($match_number[0])) $inquiry_id = intval($match_number[0]);
         }
         return $inquiry_id;
@@ -321,19 +332,14 @@ class Inqman_PopServer
      */
     protected function _parse($message)
     {
-        //$from    = mb_decode_mimeheader($message->from);
-        //$subject = mb_decode_mimeheader($message->subject);
-        //$subject = mb_convert_encoding($subject, "UTF-8", "ASCII,JIS,UTF-8,EUC-JP,SJIS");
         $from       = $message->from;
         $subject    = $message->subject;
         $priority   = $this->_getPriority($message->getHeaders());
         $message_id = $this->_getMessageId($message->getHeaders());
-        //echo "Mail from '{$from}' : {$subject} : Priority:{$priority} \n";
     
         $content = "";
         if ($message->isMultipart()) {
             $partCount = $message->countParts();
-            //echo "this mail has {$partCount} parts\n";
     
             for($i=1; $i<=$partCount; $i++) {
                 $part = $message->getPart($i);
@@ -342,10 +348,8 @@ class Inqman_PopServer
                 }
             }
         } else {
-            //echo "this mail has single parts\n";
             $content = mb_convert_encoding($message->getContent(), "UTF-8", "ASCII,JIS,UTF-8,EUC-JP,SJIS");
         }
-        //echo "content:\n {$content}\n";
         
         $result = array(
                 'from'       => $from,
@@ -393,8 +397,6 @@ class Inqman_PopServer
             }
         }
         //メールボディを取得する
-        //TODO Content = Body? or Header+Body?
-        //$content = $message->getContent();
         $parsed_message = $this->_parse($message);
         $content = $parsed_message['content'];
         
@@ -486,5 +488,3 @@ class Inqman_PopServer
     }
     
 }
-
-?>
