@@ -577,8 +577,8 @@ CREATE TABLE IF NOT EXISTS `t_mailtemplate` (
 --
 
 INSERT INTO `t_mailtemplate` (`id`, `name`, `subject`, `content`, `mail_from`, `service_id`) VALUES
-(1, '登録知用テンプレート', '問合せが登録されました：{$inquiry_subject}', '「{$service_name}」に問い合わせが登録されました。\r\nSubject:{$inquiry_subject}\r\nFrom:{$inquiry_received_from}\r\n\r\n----------------------- \r\n\r\n{$inquiry_content}\r\n\r\n----------------------- \r\nこのメールはINQMANにより発行されました。', '{$service_inquiry_mailaddress}', 1),
-(2, '起票知用テンプレート', '問合せが起票（受付）されました：{$inquiry_subject}', '「{$service_name}」の問い合わせ「{$inquiry_subject}」が起票（受付）されました。\r\nSubject:{$inquiry_subject}\r\nFrom:{$inquiry_received_from}\r\n\r\n----------------------- \r\n\r\n{$inquiry_content}\r\n\r\n----------------------- \r\nこのメールはINQMANにより発行されました。', '{$service_inquiry_mailaddress}', 1),
+(1, '登録通知用テンプレート', '問合せが登録されました：{$inquiry_subject}', '「{$service_name}」に問い合わせが登録されました。\r\nSubject:{$inquiry_subject}\r\nFrom:{$inquiry_received_from}\r\n\r\n----------------------- \r\n\r\n{$inquiry_content}\r\n\r\n----------------------- \r\nこのメールはINQMANにより発行されました。', '{$service_inquiry_mailaddress}', 1),
+(2, '起票通知用テンプレート', '問合せが起票（受付）されました：{$inquiry_subject}', '「{$service_name}」の問い合わせ「{$inquiry_subject}」が起票（受付）されました。\r\nSubject:{$inquiry_subject}\r\nFrom:{$inquiry_received_from}\r\n\r\n----------------------- \r\n\r\n{$inquiry_content}\r\n\r\n----------------------- \r\nこのメールはINQMANにより発行されました。', '{$service_inquiry_mailaddress}', 1),
 (3, '却下通知用テンプレート', '問い合わせが却下されました：{$inquiry_subject}', '問い合わせ「{$inquiry_subject}」が起票されました。\r\nSubject:{$inquiry_subject}\r\nFrom:{$inquiry_received_from}\r\n\r\n----------------------- \r\n\r\n{$inquiry_content}\r\n\r\n----------------------- \r\nこのメールはINQMANにより発行されました。', '{$service_inquiry_mailaddress}', 1),
 (4, '承認通知用テンプレート', '問い合わせが承認されました：{$inquiry_subject}', '問い合わせ「{$inquiry_subject}」が承認されました。\r\nSubject:{$inquiry_subject}\r\nFrom:{$inquiry_received_from}\r\n\r\n----------------------- \r\n\r\n{$inquiry_content}\r\n\r\n----------------------- \r\nこのメールはINQMANにより発行されました。', '{$service_inquiry_mailaddress}', 1),
 (5, '回答通知用テンプレート', '回答がありました：{$reply_subject}', '「{$service_name}」の問い合わせ「{$inquiry_subject}」に回答がありました。\r\nSubject:{$reply_subject}\r\nFrom:{$reply_received_from}\r\n\r\n----------------------- \r\n\r\n{$reply_content}\r\n\r\n----------------------- \r\nこのメールはINQMANにより発行されました。', '{$service_comment_mailaddress}', 1),
